function [YPred DecisionValue] = tecl_mkmtfl_md(beta,bias,trInd,teInd,changeLabel)
%function [YPred] = tecl_mkmtfl(beta,bias,trInd,teInd)
%Predicts the labels of test examples using models specified by trcl_mkmtfl
%INPUT:
%GLOBAL VARIABLES:
%K - 3-d matrix such that K(:,:,j) is the gram-matrix of examples
%    from all the tasks with the jth kernel
%ARGUMENTS:
%trInd - Tx1 cell such that trInd{t} is a column vector of train. indices into
%        K (MUST BE SAME AS in trrg_mkmtfl)
%trInd - Tx1 cell such that teInd{t} is a column vector of test. indices into K
%beta, bias - output of trcl_mkmtfl.m
%OUPUT:
%YPred - 3-d cell, YPred{k,c,t} gives predicted labels for
%        pk(k),C(c) and t^th task. It is a column vector of labels.

global K

pkLen = size(beta,1);
CLen = size(beta,2);
T = size(beta,3);
k = size(beta,4);
totTrInd = [];
for t=1:T
    totTrInd = [totTrInd;trInd{t}];
end

for pkInd=1:pkLen
        for CInd=1:CLen
            for t=1:T
                %Compute the predictions
                YPred{pkInd,CInd,t} = -bias{pkInd,CInd,t}*ones(length(teInd{t}),1);
                for j=1:k
                    YPred{pkInd,CInd,t} = YPred{pkInd,CInd,t} + K(teInd{t},totTrInd,j)*beta{pkInd,CInd,t,j};
                end
                DecisionValue{pkInd,CInd,t} = YPred{pkInd,CInd,t}*changeLabel(t);
                YPred{pkInd,CInd,t} = sign(YPred{pkInd,CInd,t});
            end
        end
end
